/*
Fibres optiques

Copyright (C) 2012 Observatoire de Paris-Meudon
 
Auteur : Benjamin Mollier

Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier conformment aux dispositions de la Licence Publique Gnrale GNU, telle que publie par la Free Software Foundation ; version 2 de la licence, ou encore ( votre choix) toute version ultrieure.

Ce programme est distribu dans l'espoir qu'il sera utile, mais SANS AUCUNE GARANTIE ; sans mme la garantie implicite de COMMERCIALISATION ou D'ADAPTATION A UN OBJET PARTICULIER. Pour plus de dtail, voir la Licence Publique Gnrale GNU .

Vous devez avoir reu un exemplaire de la Licence Publique Gnrale GNU en mme temps que ce programme ; si ce n'est pas le cas, crivez  la Free Software Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, Etats-Unis.
*/

import simu.*;

/**
 * Algorithme de simulation pour SimuApplet.
 * Simule la propagation de rayons lumineux dans une fibre optique
 * 
 * compilation: javac -source 1.2 -target 1.1 -encoding ISO-8859-1 -classpath SimuLab.jar FibresOptiques.java
 */
public class FibresOptiques extends SimuApplet 
{

    //----- I. Variable globales ------------------------------------------------------------------------------------------------------------------
		// - - - I.1 Coordonnes des rayons incidents et rflchis (x1,y1) et rfract (x2,y2) - - - -
			double x1,y1;
			double dx1,dy1;
			double s;
			int f;
	
		// - - - I.2 Pas pour tracs les rayons - - - 
			double ds = 0.01;
	
		// - - - I.3 Angles rflchi et rfract - - -
			
			double i1;
			double i2;
			double ic,rc;
			double ig,rg;
			double ia;
			
			double nc,ng;
	
		// - - - I.4 Options graphiques - - -
			String s1,s2;
	
	
	
			    
    //----- II. Constructeur de la classe, avec la dfinition des paramtres de simulation et des options d'affichage. ----------------------------
    public FibresOptiques() 
	{
        appletDoc("FibresOptiques_doc.xml");
	}
	
	//----- III. Calcul des rayons ----------------------------------------------------------------------------------------------------------------
		// - - - III.1 Calcul live (utilis avec affichage "plotlive") - - - - 
			// - 3.1.1 Initialisation -
				public void initCalculLive(ListeValeurs in) throws SimuException 
				{
					// - 3.1.1.1 Chargement des variables d'entre -
					i1 = in.lireDouble("i1");
					nc = in.lireDouble("nc");
					ng = in.lireDouble("ng");
					
					
					// - 3.1.1.2 Initialisation des coordonnes -
					s  =  -5;
					x1 =  s * Math.cos(i1/180.*Math.PI);
					y1 =  s * Math.sin(i1/180.*Math.PI);
		
					// - 3.1.1.3 Calcul des angles rflchi et rfract
					//r1 = -i1;
					//i2 = 180/Math.PI * Math.asin(nc/ng*Math.sin(i1/180*Math.PI));
					i2 = 180/Math.PI * Math.asin(1./nc*Math.sin(i1/180*Math.PI));
					ic = 90.-i2;
					rc = -ic;
					ig = 180/Math.PI * Math.asin(nc/ng*Math.sin(ic/180*Math.PI));
					ia = 180/Math.PI * Math.asin(ng/1.*Math.sin(ig/180*Math.PI));
				}
			// - 3.1.2 Calcul de l'abscisse curviligne s  s+ds
				public ListeValeurs calculLive() throws SimuException 
				{
					ListeValeurs out = new ListeValeurs();
					
					if (x1 < 0)
					{
						dx1 =  ds * Math.cos(i1/180.*Math.PI);
						dy1 =  ds * Math.sin(i1/180.*Math.PI);
					}
					else if (x1 < 16)
					{
						if (Math.abs(y1)<=2)
						{
							
							dx1 =  ds * Math.cos(i2/180.*Math.PI);
							dy1 =  ds * Math.sin(i2/180.*Math.PI);
							
							
						}
						else if (ig <= 90 && ig > 0)
						{
							if (Math.abs(y1)<=3)
							{
								dx1 =  ds * Math.cos((90-ig)/180.*Math.PI);
								dy1 =  ds * Math.sin((90-ig)/180.*Math.PI);
							}
							else if(Math.abs(y1)<=5)
							{
								dx1 =  ds * Math.cos((90-ia)/180.*Math.PI);
								dy1 =  ds * Math.sin((90-ia)/180.*Math.PI);
							}
						}
						else
						{
							i2 = -i2;
							dx1 =  2 * ds * Math.cos(i2/180.*Math.PI);
							dy1 =  2 * ds * Math.sin(i2/180.*Math.PI);
						}
					}
					else
						return null; 
        
					x1 +=  dx1;
					y1 +=  dy1;
					
					out.ajouterDouble("x1", x1);
					out.ajouterDouble("y1", y1);
					
					
					dormir(Math.round(ds*100)); // pour bloquer le programme pendant ds secondes
					
					return out;
				}
    
    // - - - III.2 Calcul complet d'un coup (utilis avec les affichages "plot" et "tableau") - - - - 
    /*public ListeValeurs calcul(ListeValeurs in) throws SimuException 
	{
		ListeValeurs out = new ListeValeurs();
		
		// - 3.1.1.1 Chargement des variables d'entre -
		nc = in.lireDouble("nc");
		ng = in.lireDouble("ng");
		s1 = in.lireString("s1");
		s2 = in.lireString("s2");
		
		
		for (i1 = 0; i1 <= 90 ; i1 = i1 + 0.1)
		{
			r1 = -i1;
			i2 = 180/Math.PI * Math.asin(nc/ng*Math.sin(i1/180*Math.PI));
			
			out.ajouterDouble("x1", x1);
			out.ajouterDouble("y1", y1);
			out.ajouterDouble("i1", i1);
			out.ajouterDouble("i2", i1);
			out.ajouterDouble("r1", r1);
			out.ajouterDouble("i1b", ("on".equals(s1)?Math.sin(i1/180*Math.PI):i1));
			out.ajouterDouble("i2b" , ("on".equals(s2)?Math.sin(i2/180*Math.PI):i2));
		}
		return out;
	}*/
}
