/*
Fibres optiques

Copyright (C) 2012 Observatoire de Paris-Meudon
 
Auteur : Benjamin Mollier
Conversion en Javascript : Damien Guillaume

Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier conformément aux dispositions de la Licence Publique Générale GNU, telle que publiée par la Free Software Foundation ; version 2 de la licence, ou encore (à votre choix) toute version ultérieure.

Ce programme est distribué dans l'espoir qu'il sera utile, mais SANS AUCUNE GARANTIE ; sans même la garantie implicite de COMMERCIALISATION ou D'ADAPTATION A UN OBJET PARTICULIER. Pour plus de détail, voir la Licence Publique Générale GNU .

Vous devez avoir reçu un exemplaire de la Licence Publique Générale GNU en même temps que ce programme ; si ce n'est pas le cas, écrivez à la Free Software Foundation Inc., 675 Mass Ave, Cambridge, MA 02139, Etats-Unis.
*/

/**
 * Algorithme de simulation pour SimuApplet.
 * Simule la propagation de rayons lumineux dans une fibre optique
 */

new FibresOptiques();

//----- I. Constructeur de la classe, avec la définition des paramètres de simulation et des options d'affichage.
function FibresOptiques() {
//----- Variable globales
    // - - - I.1 Coordonnées des rayons incidents et réfléchis (x1,y1) et réfracté (x2,y2) - - - -
        this.x1 = 0.;
        this.y1 = 0.;
        this.dx1 = 0.;
        this.dy1 = 0.;
        this.s = 0.;
        this.f = 0;

    // - - - I.2 Pas pour tracés les rayons - - - 
        this.ds = 0.1;

    // - - - I.3 Angles réfléchi et réfracté - - -
        
        this.i1 = 0.;
        this.i2 = 0.;
        this.ic = 0.;
        this.rc = 0.;
        this.ig = 0.;
        this.rg = 0.;
        this.ia = 0.;
        
        this.nc = 0.;
        this.ng = 0.;

    // - - - I.4 Options graphiques - - -
        this.s1 = '';
        this.s2 = '';
    
    this.applet = new SimuApplet(this);
    this.applet.appletDoc('fibres_optiques_doc.xml');
    this.applet.setDelaiIterations(Math.round(this.ds * 100));
}

	//----- II. Calcul des rayons
		// - - - II.1 Calcul live (utilisé avec affichage "plotlive") - - - - 
			// - 2.1.1 Initialisation -
FibresOptiques.prototype.initCalculLive = function(lin) {
    // - 2.1.1.1 Chargement des variables d'entrée -
    this.i1 = lin.lireDouble('i1');
    this.nc = lin.lireDouble('nc');
    this.ng = lin.lireDouble('ng');
    
    
    // - 2.1.1.2 Initialisation des coordonnées -
    this.s  =  -5;
    this.x1 =  this.s * Math.cos(this.i1 / 180. * Math.PI);
    this.y1 =  this.s * Math.sin(this.i1 / 180. * Math.PI);

    // - 2.1.1.3 Calcul des angles réfléchi et réfracté
    this.i2 = 180 / Math.PI * Math.asin(1. / this.nc * Math.sin(this.i1 / 180 * Math.PI));
    this.ic = 90. - this.i2;
    this.rc = -this.ic;
    this.ig = 180 / Math.PI * Math.asin(this.nc / this.ng * Math.sin(this.ic / 180 * Math.PI));
    this.ia = 180 / Math.PI * Math.asin(this.ng / 1. * Math.sin(this.ig / 180 * Math.PI));
}

			// - 2.1.2 Calcul de l'abscisse curviligne s à s+ds
FibresOptiques.prototype.calculLive = function() {
    var out;
    
    out = new ListeValeurs();
    
    if (this.x1 < 0)
    {
        this.dx1 =  this.ds * Math.cos(this.i1 / 180. * Math.PI);
        this.dy1 =  this.ds * Math.sin(this.i1 / 180. * Math.PI);
    }
    else if (this.x1 < 16)
    {
        if (Math.abs(this.y1) <= 2)
        {
            
            this.dx1 =  this.ds * Math.cos(this.i2 / 180. * Math.PI);
            this.dy1 =  this.ds * Math.sin(this.i2 / 180. * Math.PI);
            
            
        }
        else if (this.ig <= 90 && this.ig > 0)
        {
            if (Math.abs(this.y1) <= 3)
            {
                this.dx1 =  this.ds * Math.cos((90 - this.ig) / 180. * Math.PI);
                this.dy1 =  this.ds * Math.sin((90 - this.ig) / 180. * Math.PI);
            }
            else if (Math.abs(this.y1) <= 5)
            {
                this.dx1 =  this.ds * Math.cos((90 - this.ia) / 180. * Math.PI);
                this.dy1 =  this.ds * Math.sin((90 - this.ia) / 180. * Math.PI);
            }
        }
        else
        {
            this.i2 = -this.i2;
            this.dx1 =  2 * this.ds * Math.cos(this.i2 / 180. * Math.PI);
            this.dy1 =  2 * this.ds * Math.sin(this.i2 / 180. * Math.PI);
        }
    }
    else
        return null; 

    this.x1 +=  this.dx1;
    this.y1 +=  this.dy1;
    
    out.ajouterDouble('x1', this.x1);
    out.ajouterDouble('y1', this.y1);
    
    return out;
}
